<?php

namespace App\Http\Controllers;

use App\Models\Blog;
use Illuminate\Http\Request;
use Illuminate\Support\Str ;
use Illuminate\Support\Facades\File;

class BlogController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $blogs  = Blog::get();
        return view('admin.admin_blogs',compact('blogs'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.createblog');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // return $request->all();
        $request->validate([
            'description' => 'required',
            'image' => 'required|max:2048',
            'title' => 'required|unique:blogs,title', 
        ]);

        $blog = new Blog();
        $blog->title = $request->title;
        $blog->slug = Str::Slug($request->title,"-");
        $blog->description = $request->description;
        $blog->status = 1;
        if($request->image){
            $filename = time() . '.' . $request->image->extension();
            $request->image->move(public_path('blog'), $filename);
            $blog->image = $filename;
        }
        $blog->save();
        $notification = array('message' => 'Blog Added Successfully! ', 'alert-type' => 'success');
        return redirect()->route('admin-blogs')->with($notification);
    }

    /**
     * Display the specified resource.
     */
    public function show(Blog $blog)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request, $id)
    {
        $edit = Blog::find($id);
        return view('admin.editblog',compact('edit'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $request->validate([
            'description' => 'required',
            'title' => 'required|max:200', 
        ]);

        $edit_blog = Blog::find($id);
        $edit_blog->title = $request->title;
        $edit_blog->slug = Str::Slug($request->title,"-");
        $edit_blog->description = $request->description;
        $edit_blog->status = 1;
        if ($request->hasFile('image')) {
            File::delete(public_path('blog/'.$edit_blog->image));
        }
        if($request->image){
            $filename = time() . '.' . $request->image->extension();
            $request->image->move(public_path('blog'), $filename);
            $edit_blog->image = $filename;
        }
        $edit_blog->save();
        $notification = array('message' => 'Blog Updated Successfully! ', 'alert-type' => 'success');
        return redirect()->route('admin-blogs')->with($notification);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request,$id)
    {
       $delete = Blog::find($id);
       $delete->delete();
       $notification = array('message' => 'Blog Deleted Successfully! ', 'alert-type' => 'success');
       return redirect()->route('admin-blogs')->with($notification);
    }
}
