<?php

namespace App\Http\Controllers;

use App\Models\Cities;
use App\Models\Countries;
use App\Models\States;
use App\Models\User;
use App\Models\UserEducation;
use App\Models\UserExperience;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use App\Models\SaveJob;
use Illuminate\Support\Facades\Cache;


class CondidateController extends Controller
{
    public function index()
    {
        return view('candidate.candidate-dashboard');
    }

    public function candidateProfile()
    {
        $data['userData'] = User::where('id', Auth::user()->id)->first()->toArray();
        $cities  = Cities::get();
        // $states = States::get();
        // $countries = Countries::get();
         $states = Cache::remember('states', now()->addHours(24), function () {
        return States::all();
    });
        // $countries = Countries::get();
        // Example caching in the controller method where you fetch countries
    $countries = Cache::remember('countries', now()->addHours(24), function () {
        return Countries::all();
    });

        return view('candidate.candidate-profile', $data,get_defined_vars());
    }

    public function getStates($countryId)
    {
        $states = States::where('country_id', $countryId)->pluck('name', 'id');
        return view('partials.states', compact('states'));
    }

    public function getCities($stateId)
    {
        $cities = Cities::where('state_id', $stateId)->pluck('name', 'id');
        return view('partials.cities', compact('cities'));
    }

    public function profileUpdate(Request $request)
    {
        $request->validate([
            'name' => 'nullable|string|max:255',
            'about' => 'nullable|string',
            'photo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Adjust validation rules for the photo as needed
            'facebookUrl' => 'nullable|url',
            'linkedInUrl' => 'nullable|url',
            'address' => 'nullable|string|max:255',
            'country' => 'nullable|string',
            'state' => 'nullable|string',
            'city' => 'nullable|string',
            'zipCode' => 'nullable|numeric',
        ]);

        $user = User::find(auth()->user()->id);
        $user->name = $request->name;
        $user->about = $request->about;
        $user->facebook_url = $request->facebookUrl;
        $user->linkedin_url = $request->linkedInUrl;
        $user->address = $request->address;
        $user->country_id = $request->country;
        $user->state_id = $request->state;
        $user->city_id = $request->city;
        $user->zip_code = $request->zipCode;

        if ($request->hasFile('photo')) {
            // Delete the old photo if it exists
            if ($user->photo) {
                $path = public_path('images/userDp/' . $user->photo);
                $userPhotoPath = str_replace('\\', '/', $path);
                $oldPhotoPath = $userPhotoPath;
                //dd($oldPhotoPath);
                // dd(  $oldPhotoPath );
                if (File::exists($oldPhotoPath)) {
                    dd('yes');
                    File::delete($oldPhotoPath);
                }
            }

            // Get the uploaded file instance
            $photo = $request->file('photo');

            // Generate a unique name for the file
            $photoName = time() . '_' . $photo->getClientOriginalName();

            // Move the file to the public/images/userDp directory
            $photo->move(public_path('public/images/userDp'), $photoName);

            // Save the file path in the user's photo field in the database
            $user->photo = $photoName;
        }

        // Save the updated user data
        $user->save();
        $notification = array('message' => 'Profile updated successfully!', 'alert-type' => 'success');
        return redirect()->back()->with($notification);
        // return redirect()->back()->with('success', 'Profile updated successfully!');
    }

    public function resume()
    {
        $my_education  = UserEducation::where('user_id',Auth::id())->first();
        $my_experience = UserExperience::where('user_id',Auth::id())->first();
        return view('candidate.candidate-resume',get_defined_vars());
    }

    public function resumeStore(Request $request)
    {
        // return $request->video_url;
        // return ;

        $this->validate($request,[
            'educationTitle' => 'nullable|string',
            'academy' => 'nullable|string',
            'educationYearFrom' => 'nullable|integer',
            'educationYearTo' => 'nullable|integer',
            'educationDiscription' => 'nullable|string',
            'experienceTitle' => 'nullable|string',
            'company' => 'nullable|string',
            'experienceYearFrom' => 'nullable|integer',
            'experienceYearTo' => 'nullable|integer',
            'experienceDiscription' => 'nullable|string',
            'overview' => 'required',
            'uploadCV' => 'required',
            'minimum_salary' => 'required|max:200',
            'maximum_salary' => 'required|max:200',
        ]);
    
        $education = UserEducation::updateOrCreate(
            // dd($request->skills),
            ['user_id' => auth()->user()->id],
            [
                'title' => $request->educationTitle,
                'academy' => $request->academy,
                'start_year' => $request->educationYearFrom,
                'end_year' => $request->educationYearTo,
                'description' => $request->educationDiscription,
            ]
        );
        $id =  $education->id;
        if($request->uploadCV){
            $filename = time() . '.' . $request->uploadCV->extension();
            $request->uploadCV->move(public_path('candidate-cv'), $filename);
        }
        $experience = UserExperience::updateOrCreate(
            // dd($request->skills),
            ['user_id' => auth()->user()->id],
            
            [
                'title' => $request->experienceTitle,
                'company' => $request->company,
                'start_year' => $request->experienceYearFrom,
                'end_year' => $request->experienceYearTo,
                'description' => $request->experienceDiscription,
                'overview' => $request->overview,
                'skills' => implode(',', $request->skills),
                'video_url' => $request->video_url,
                'minimum_salary' => $request->minimum_salary,
                'maximum_salary' => $request->maximum_salary,
                'location' => $request->location,
                'experience' => $request->experience,
                'english_fluency' => $request->english_fluency,
                'cv' => $filename, // You can handle CV upload separately
                'education_id' =>  $id, // Assign the education ID here
            ]
        );
    
        $notification = array('message' => 'Resume Updated Successfully!', 'alert-type' => 'success');
        return redirect()->back()->with($notification);
    } 
    
       
    
    public function jobAlert(Request $request){
        return view('candidate.candidate-job-alert');
    }
    public function savedJobs(Request $request){
        $saved_jobs  = SaveJob::where('user_id',Auth::id())->with('get_job.get_employer')->get();
        // return $saved_jobs;
        return view('candidate.candidate-saved-jobs',get_defined_vars());
    }
    public function accountSetting(Request $request){
        return view('candidate.candidate-settings');
    }
}
