<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\PostJob;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Str;
use App\Models\Cities;
use App\Models\Countries;
use App\Models\States;
use Illuminate\Support\Facades\Cache;

class EmployerController extends Controller
{
    public function index(){
        return view('employer.employer-dashboard');
    }

    public function employerProfile(){
        $data['userData'] = User::where('id', Auth::user()->id)->first()->toArray();
        $cities  = Cities::get();
        
        // $states = States::get();
        $states = Cache::remember('states', now()->addHours(24), function () {
        return States::all();
    });
        // $countries = Countries::get();
        // Example caching in the controller method where you fetch countries
    $countries = Cache::remember('countries', now()->addHours(24), function () {
        return Countries::all();
    });

        return view('employer.employer-profile',$data,get_defined_vars());
    }

    public function profileUpdate(Request $request){

        // dd($request->all());
        $request->validate([
            'name' => 'nullable|string|max:255',
            'about' => 'nullable|string',
            'photo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Adjust validation rules for the photo as needed
            'facebookUrl' => 'nullable|url',
            'linkedInUrl' => 'nullable|url',
            'website' => 'nullable|url',
            'address' => 'nullable|string|max:255',
            'country' => 'nullable|string',
            'comapny' =>  'nullable|numeric',
            'phone' =>  'nullable|numeric',
            'foundedDate' =>  'nullable',
            'category' =>  'nullable|string',
            'state' => 'nullable|string',
            'city' => 'nullable|string',
            'zipCode' => 'nullable|numeric',
        ]);

        $user = User::where('id',Auth::id())->first();
        $user->name = $request->input('name');
        $user->founded_date = $request->input('foundedDate');
        $user->category = $request->input('category');
        $user->website = $request->input('website');
        $user->phone_number = $request->input('phone');
        $user->about = $request->input('about');
        $user->facebook_url = $request->input('facebookUrl');
        $user->linkedin_url = $request->input('linkedInUrl');
        $user->address = $request->input('address');
        $user->company_size = $request->input('comapny');
        $user->country_id = $request->input('country');
        $user->state_id = $request->input('state');
        $user->city_id = $request->input('city');
        $user->zip_code = $request->input('zipCode');

        if ($request->hasFile('photo')) {
            // Delete the old photo if it exists
            if ($user->photo) {
                $path = public_path('images/userDp/' . $user->photo);
                $userPhotoPath = str_replace('\\', '/', $path);
                $oldPhotoPath = $userPhotoPath;
                //dd($oldPhotoPath);
                // dd(  $oldPhotoPath );
                if (File::exists($oldPhotoPath)) {
                    dd('yes');
                    File::delete($oldPhotoPath);
                }
            }

            // Get the uploaded file instance
            $photo = $request->file('photo');

            // Generate a unique name for the file
            $photoName = time() . '_' . $photo->getClientOriginalName();

            // Move the file to the public/images/userDp directory
            $photo->move(public_path('public/images/userDp'), $photoName);

            // Save the file path in the user's photo field in the database
            $user->photo = $photoName;
        }

        // Save the updated user data
        $user->save();
        $notification = array('message' => 'Profile updated successfully!', 'alert-type' => 'success');
        return back()->withInput()->with($notification);
        // return redirect()->back()->with('success', 'Profile updated successfully!');
    }
    public function employerJobs(Request $request){
        $my_jobs  = PostJob::where('user_id',Auth::id())->get();
        return view('employer.employer-jobs',get_defined_vars());
    }
    public function postJob(Request $request){
        return view('employer.employer-submit-job');
    }
    public function savedCandidates(Request $request){
        return view('employer.employer-saved-candidates');
    }
    public function empMembership(Request $request){
        return view('employer.employer-membership');
    }
    public function accountSetting(Request $request){
        return view('employer.employer-settings');
    }
    public function addJob(Request $request){
        $this->validate($request,[
            'english_fluency' => 'required|max:200',
            'industry' => 'required|max:200',
            'location' => 'required|max:200',
            'experience' => 'required|max:200',
            'skills'=>'required|max:200',
            'max_salary'=>'required|max:200',
            'min_salary' => 'required|max:200',
            'salary' => 'required|max:200',
            'job_type' => 'required|max:200',
            'job_category' => 'required|max:200',
            'benefits' => 'required',
            'job_skills' => 'required',
            'responsibilities' => 'required',
            'job_description' => 'required',
            'overview' => 'required',
            'job_title' => 'required|max:100',
         ]);
          $job = new PostJob();
          $job->user_id =  Auth::id();
          $job->job_title =  $request->job_title;
          $job->slug = Str::slug($request->job_title,'-');
          $job->job_description =  $request->job_description;
          $job->job_category =  $request->job_category;
          $job->job_type =  $request->job_type;
          $job->salary =  $request->salary;
          $job->min_salary =  $request->min_salary;
          $job->max_salary =  $request->max_salary;
          $job->skills =  implode(',', $request->skills);
          $job->experience =  $request->experience;
          $job->location =  $request->location;
          $job->industry =  $request->industry;
          $job->english_fluency =  $request->english_fluency;
          $job->overview =  $request->overview;
          $job->job_skills =  $request->job_skills;
          $job->benefits =  $request->benefits;
          $job->responsibilities =  $request->responsibilities;
          $job->status = 1;
          $job->save();
          $notification = array('message' => 'Job Posted Successfully! ', 'alert-type' => 'success');
          return back()->withInput()->with($notification);
    }

    public function editJob(Request $request,$id){
        $edit = PostJob::find($id);
        if(!empty($edit)){
            return view('employer.employer-edit-job',get_defined_vars());
        }else {
            return back();
        }
    }
    public function updateJob(Request $request,$id){
        $this->validate($request,[
            'english_fluency' => 'required|max:200',
            'industry' => 'required|max:200',
            'location' => 'required|max:200',
            'experience' => 'required|max:200',
            'skills'=>'required|max:200',
            'max_salary'=>'required|max:200',
            'min_salary' => 'required|max:200',
            'salary' => 'required|max:200',
            'job_type' => 'required|max:200',
            'job_category' => 'required|max:200',
            'benefits' => 'required',
            'job_skills' => 'required',
            'responsibilities' => 'required',
            'job_description' => 'required',
            'overview' => 'required',
            'job_title' => 'required|max:100',
         ]);
        $update_job = PostJob::find($id);
        $update_job->job_title =  $request->job_title;
        $update_job->slug = Str::slug($request->job_title,'-');
        $update_job->job_description =  $request->job_description;
        $update_job->job_category =  $request->job_category;
        $update_job->job_type =  $request->job_type;
        $update_job->salary =  $request->salary;
        $update_job->min_salary =  $request->min_salary;
        $update_job->max_salary =  $request->max_salary;
        $update_job->skills =  implode(',', $request->skills);
        $update_job->experience =  $request->experience;
        $update_job->location =  $request->location;
        $update_job->industry =  $request->industry;
        $update_job->english_fluency =  $request->english_fluency;
        $update_job->overview =  $request->overview;
        $update_job->job_skills =  $request->job_skills;
        $update_job->benefits =  $request->benefits;
        $update_job->responsibilities =  $request->responsibilities;
        $update_job->status = 1;
        $update_job->save();
        $notification = array('message' => 'Job Updated Successfully! ', 'alert-type' => 'success');
        return redirect()->route('employer-jobs')->with($notification);
    }
    public function deleteEmployeJob(Request $request,$id){
        $del_job = PostJob::find($id);
        $del_job->delete();
        $notification = array('message' => 'Job Deleted Successfully! ', 'alert-type' => 'success');
        return back()->with($notification);
    }

    public function jobStatus(Request $request,$id){
        $job_status = PostJob::find($id);
        if($job_status->status == 0){
            $job_status->status =1;
        }else {
            $job_status->status =0;
        }
        $job_status->save();
        $notification = array('message' => 'Job Status Updated Successfully ! ', 'alert-type' => 'success');
        return back()->with($notification);
    }
}
