<?php

use App\Http\Controllers\CondidateController;
use App\Http\Controllers\EmployerController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\FrontendController;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\BlogController;
use App\Http\Controllers\PaymentController;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/
Route::post('/logout', function () {
    Auth::logout();
    return redirect('/');
})->name('logout');
Route::get('/', function () {
    $candidates  = UserExperience::get();
    return $candidates;
    return view('pages.home');
});
Route::get('admin',function(){
    return view('admin.admin_login');
});

Route::post('admin-login',[AdminController::class,'adminLogin'])->name('admin-login');


Route::group(['middleware' =>  ['preventBackHistory','adminmiddleware'],'prefix' => 'admin'],function () {

    Route::get('dashboard',[AdminController::class,'index'])->name('admin-dashboard');
    Route::get('users',[AdminController::class,'adminUsers'])->name('admin-users');
    Route::get('candidates',[AdminController::class,'allCandidates'])->name('admin-candidates');
    Route::get('jobs',[AdminController::class,'adminJobs'])->name('admin-jobs');
    Route::get('post-job',[AdminController::class,'adminPostJob'])->name('admin-postjob');
    Route::get('admin-logout',[AdminController::class,'adminLogout'])->name('admin-logout');
    Route::get('contacts',[AdminController::Class,'contacts'])->name('admin-contacts');
    Route::get('blogs',[BlogController::class,'index'])->name('admin-blogs');
    Route::get('create-blog',[BlogController::Class,'create'])->name('admin-createblog');
    Route::post('add-blog',[BlogController::Class,'store'])->name('add-blog');
    Route::get('edit-blog/{id}',[BlogController::Class,'edit'])->name('edit-blog');
    Route::post('update-blog/{id}',[BlogController::class,'update'])->name('update-blog');
    Route::get('delete-blog/{id}',[BlogController::class,'destroy'])->name('delete-blog');
});

Route::group(['middleware' =>  ['preventBackHistory','candidatemiddleware'],'prefix' => 'candidate'],function () {

    Route::get('dashboard', [CondidateController::class, 'index'])->name('candidateDashboard');
    Route::get('profile', [CondidateController::class, 'candidateProfile'])->name('candidateProfile');
    Route::post('profile-update', [CondidateController::class, 'profileUpdate'])->name('profileUpdate');
    Route::get('resume', [CondidateController::class, 'resume'])->name('resume');
    Route::post('resume-store', [CondidateController::class, 'resumeStore'])->name('resumeStore');
    Route::get('job-alert',[CondidateController::class,'jobAlert'])->name('job-alert');
    Route::get('saved-jobs',[CondidateController::class,'savedJobs'])->name('saved-jobs');
    Route::get('account-setting',[CondidateController::class,'accountSetting'])->name('account-setting');
});

        Route::get('/get-states/{countryId}',[CondidateController::class, 'getStates'])->name('getStates');
        Route::get('/get-cities/{stateId}',[CondidateController::class, 'getCities'])->name('getCities');

Route::group(['middleware' =>  ['preventBackHistory','employermiddleware'],'prefix' => 'employer'],function () {
    Route::get('dashboard', [EmployerController::class, 'index'])->name('employerDashboard');
    Route::get('profile', [EmployerController::class, 'employerProfile'])->name('employerProfile');
    Route::post('employee-update', [EmployerController::class, 'profileUpdate'])->name('employerUpdate');
    Route::get('jobs', [EmployerController::class, 'employerJobs'])->name('employer-jobs');
    Route::get('post-job',[EmployerController::class,'postJob'])->name('post-job');
    Route::get('saved-candidates',[EmployerController::class,'savedCandidates'])->name('saved-candidates');
    Route::get('membership',[EmployerController::class,'empMembership'])->name('membership');
    Route::get('account-settings',[EmployerController::class,'accountSetting'])->name('account-settings');
    Route::post('add-job',[EmployerController::Class,'addJob'])->name('add-job');
    Route::get('edit-job/{id}',[EmployerController::Class,'editJob'])->name('edit-job');
    Route::post('update-job/{id}',[EmployerController::class,'updateJob'])->name('update-job');
    Route::get('remove-job/{id}',[EmployerController::class,'deleteEmployeJob'])->name('remove-job');
    Route::get('job-status/{id}',[EmployerController::Class,'jobStatus'])->name('job-status');
});


// Frontend routes
Route::get('purchase-plan',[PaymentController::class,'pay'])->name('purchase-plan');
Route::post('/dopay/online', [PaymentController::class,'handleonlinepay'])->name('dopay.online');
Route::get('sign-up',[FrontendController::class,'signup'])->name('sign-up');
Route::post('user-register',[FrontendController::class,'userRegister'])->name('user-register');
Route::get('login',[FrontendController::class,'login'])->name('login');
Route::post('user-login',[FrontendController::class,'userLogin'])->name('user-login');
Route::get('jobs',[FrontendController::class,'allJobs'])->name('all-jobs');
Route::get('job-details/{id}/{slug}',[FrontendController::Class,'jobDetails'])->name('job-details');
Route::get('candidates',[FrontendController::class,'allCandidates'])->name('candidates');
Route::get('candidate-details/{id}/{slug}',[FrontendController::class,'candidateDetails'])->name('candidate-details');
Route::get('blogs',[FrontendController::class,'allBlogs'])->name('blogs');
Route::get('blog-details/{slug}',[FrontendController::class,'blogDetails'])->name('blog-details');
Route::get('contact',[FrontendController::class,'contact'])->name('contact');
Route::post('save-contact',[FrontendController::class,'saveContact'])->name('save-contact');
Route::get('savejob',[FrontendController::Class,'saveJobs'])->name('savejob');
Route::get('delete-job/{id}',[FrontendController::class,'deleteJob'])->name('delete-job');
Route::get('filter-jobs',[FrontendController::class,'filterJobs'])->name('filter-jobs');
Route::get('filter-users',[FrontendController::Class,'filterUsers'])->name('filter-users');
Route::post('forget-password',[FrontendController::Class,'resetPassword'])->name('forget-password');
Route::get('/reset-password/{token}',[FrontendController::class,'getPassword'])->name('reset-password');
Route::post('update-password',[FrontendController::Class,'updatePassword'])->name('update-password');

Route::get('test',function(){
    return 'here';
});




Route::get('/users', function () {
    return view('admin.users');
});





Route::get('/job-post', function () {
    return view('admin.job-post');
});

// Route::get('blogs',[FrontendController::class,'allBlogs'])->name('blogs');

Route::get('/about-us', function () {
    return view('pages.about-us');
})->name('about-us');

Route::get('/pricing', function () {
    return view('pages.pricing');
})->name('pricing');

Route::get('/faq', function () {
    return view('pages.faq');
})->name('faq');


Route::get('/candidate-change-password', function () {
    return view('candidate.candidate-change-password');
});





Route::get('/employer-change-password', function () {
    return view('employer.employer-change-password');
});

Auth::routes();
Route::get('/', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

Auth::routes();

Route::get('/', [App\Http\Controllers\HomeController::class, 'index'])->name('home');
